import React from 'react';
import PropTypes from 'prop-types';
import modelCreator from './model';
import connect from '../../hoc/stateful';
import TableEx from '../../../components/table/index';
import styles from './index.less';

class DsTable extends React.Component {

  constructor(props, context) {
    super(props, context);
    this.loadData = this::this.loadData;
    this.state = {
      filters: [],
      current: 1,
      pageSize: 10,
    };
  }
  componentDidMount() {
    this.loadData();
  }
  loadData() {
    const psz = this.state.pageSize; // eslint-disable-line no-shadow
    const pst = (this.state.current - 1) * psz;
    this.props.dispatchLocal({ type: 'fetchData', payload: { coordinate: this.props.coordinate, pst, psz, filters: this.state.filters } });
  }
  render() {
    const { props, columns, list, num } = this.props.model;
    const tableProps = {
      dataSource: list,
      ...props,
      columns,
      filters: this.state.filters.map(filter => filter.filter),
      loading: this.props.loading.effect.fetchData,
      pagination: {
        current: this.state.current,
        total: num,
        pageSize: this.state.pageSize,
      },
      onChange: (pagination, filters, sorter) => {
        this.setState({
          current: pagination.current,
          pageSize: pagination.pageSize,
        }, () => {
          this.loadData();
        });
      },
      onFilter: (filters) => {
        this.setState({
          filters,
          current: 1,
        }, () => {
          this.loadData();
        });
      },
    };
    return (
      <div className={styles.wrapper}>
        <div className={styles.container}>
          <TableEx {...tableProps} />
        </div>
      </div>
    );
  }
}

DsTable.propTypes = {
  coordinate: PropTypes.oneOfType(
    [
      PropTypes.string,
      PropTypes.shape({
        containerType: PropTypes.string,
        containerName: PropTypes.string,
        datasourceName: PropTypes.string,
      }),
    ],
  ).isRequired,
};

export default connect(modelCreator, {
  mapStateToProps: ({ loading }) => ({ loading }),
})(DsTable);
